@@ -11,3 +11,7 @@ class Parameter(ContextBase):
         self.default_value = ''
         # self.pydantic_type = ''
         self.comment = ''
+
+    def load(self, json, force_set_value = False):
+        """需要强行设置default_value"""
+        super().load(json, force_set_value = True)
