@@ -13,7 +13,7 @@ from fastcodedog.util.inflect_wrapper import plural
 
 
 class Crud(Function):
-    POSSIBLE_IMPORTS = ['import datetime', 'from datetime import datetime', 'from datetime import date', 'from datetime import time',
+    POSSIBLE_IMPORTS = ['import datetime', 'from datetime import date', 'from datetime import time',
                         'from sqlalchemy import exists', 'from sqlalchemy import select', 'from sqlalchemy import join',
                         'from sqlalchemy import or_', 'from sqlalchemy import and_']
 
