@@ -14,6 +14,9 @@ class AdditionalMethod(Function):
                                                              nullable=parameter.nullable, comment=parameter.comment)
             if parameter.comment:
                 self.comment += f'\n:param {parameter.name}: {parameter.comment}'
+        if context.static:
+            self.decorators.append(Function.Decorator('staticmethod'))
+            self.params.pop('self')
         self.blocks.append(Text(context.script, possible_imports=context.import_))
 
     # def serialize(self, delimiter='\n', with_comment=True):
