@@ -8,16 +8,15 @@ from fastcodedog.generation.model.model import Model
 from fastcodedog.generation.model.relation_object import RelationObject
 
 
-def generate_model(models: list = None):
+def generate_model(specified_models: list = None):
     base = Base()
     base.save()
     init = Init()
     init.save()
     for module, models in ctx_instance.models.items():
         for model_context in models.values():
-            if models:
-                if model_context.name not in models:
-                    continue
+            if specified_models and model_context.name not in specified_models:
+                continue
             if model_context.is_relationship:
                 relation_object_file = File(model_context.name,
                                             file_path=LocationFinder.get_path(model_context.name, 'model', module),
