@@ -29,6 +29,9 @@ def get_unique_constraints(model):
     for unique_constraint in model.unique_constraints:
         unique_columns = []
         for key in unique_constraint:
+            if ctx_instance.tenant.enabled:     # 租户模式下，忽略租户列
+                if key == ctx_instance.tenant.local_column_code:
+                    continue
             column = model.columns[key]
             unique_columns.append(
                 {'name': column.name, 'title': column.title, 'type': column.type, 'nullable': column.nullable,
@@ -40,7 +43,8 @@ def get_unique_constraints(model):
 def get_foreign_keys(model):
     return {column.name: {'name': column.name, 'title': column.title, 'type': column.type,
                           'nullable': column.nullable,
-                          'description': column.comment} for column in model.columns.values() if column.foreign_key}
+                          'description': column.comment} for column in model.columns.values()
+            if column.foreign_key and not (ctx_instance.tenant.enabled and column.name == ctx_instance.tenant.local_column_code)}
 
 
 def get_join_relationships(model):
