@@ -9,6 +9,7 @@ from fastcodedog.prepare.pdm_to_model.after.disable_relationships import disable
 from fastcodedog.prepare.pdm_to_model.after.specified_class_names import add_specified_class_names
 from fastcodedog.prepare.pdm_to_model.after.specified_relationship_orderby import specified_relationship_orderby
 from fastcodedog.prepare.pdm_to_model.before.additional_foreign_keys import fill_additional_foreign_keys
+from fastcodedog.prepare.pdm_to_model.before.fill_tenant_id import fill_tenant_id
 from fastcodedog.prepare.pdm_to_model.before.specified_column_types import rename_specified_column_types
 from fastcodedog.prepare.pdm_to_model.before.specified_relationship_names import add_specified_relationship_names
 from fastcodedog.prepare.pdm_to_model.pdm import Pdm
@@ -24,6 +25,9 @@ def prepare_model(pre_process_scripts):
     fill_additional_foreign_keys(pdm, pre_process_scripts['additional_foreign_keys'])
     add_specified_relationship_names(pdm, pre_process_scripts['specified_relationship_names'])
     rename_specified_column_types(pdm, pre_process_scripts['specified_column_types'])
+    # 添加租户信息
+    if ctx_instance.tenant.enabled:
+        fill_tenant_id(pdm, ctx_instance.tenant.local_column_code, ctx_instance.tenant.foreign_table_code, ctx_instance.tenant.foreign_column_code)
 
     pdm.to_model()
     # 对导出后的model做些批量操作
